@@ -6,7 +6,7 @@ import os
 import uuid
 
 import numpy as np
-from numpy.testing import assert_equal, assert_raises, assert_allclose
+from numpy.testing import assert_equal, assert_raises
 from nose import with_setup
 from nose.plugins.attrib import attr
 
@@ -22,6 +22,7 @@ from brian2.core.network import schedule_propagation_offset, scheduling_summary
 from brian2.devices.device import (reinit_devices, Device, all_devices,
                                    set_device, get_device, reset_device, device)
 from brian2.utils.logger import catch_logs
+from brian2.tests.utils import assert_allclose
 
 @attr('codegen-independent')
 def test_incorrect_network_use():
@@ -1234,7 +1235,9 @@ def test_get_set_states():
     states2 = magic_network.get_states()
     states3 = net.get_states(read_only_variables=False)
     assert set(states1.keys()) == set(states2.keys()) == set(states3.keys()) == {'a_neurongroup'}
-    assert set(states1['a_neurongroup'].keys()) == set(states2['a_neurongroup'].keys()) == {'i', 'dt', 'N', 't', 'v'}
+    assert (set(states1['a_neurongroup'].keys()) ==
+            set(states2['a_neurongroup'].keys()) ==
+            {'i', 'dt', 'N', 't', 'v', 't_in_timesteps'})
     assert set(states3['a_neurongroup']) == {'v'}
 
     # Try re-setting the state
